@@ -102,7 +102,7 @@ def extract_url_metadata(args, path):
         frequency=args.frequency.value,
         category=args.category,
         time_created=int(datetime.utcnow().timestamp()),
-        time_played=None,
+        time_played=0,
         play_count=0,
     )
 
